===========
Change logs
===========

v0.1.2
======

:Date: 2025-03-22 (Asia/Tokyo)

Fixes
-----

* Disable built-in search fetures.

v0.1.1
======

:Date: 2025-03-19 (Asia/Tokyo)

Others
------

* Fix typo on README (used on PyPI).

v0.1.0
======

:Date: 2025-03-16 (Asia/Tokyo)

It is first release.

Features
--------

* Generate enhanced search page with Pagefind.

v0.0.0
======

:date: 2025-03-07 (Asia/Tokyo)

Initial commit.
